==> lasta-di-0.6.1-sources.jar: org/lastaflute/di/exception/NoSuchMethodRuntimeException.java <==
/*
 * Copyright 2014-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.lastaflute.di.exception;

import org.lastaflute.di.util.LdiMethodUtil;

/**
 * @author modified by jflute (originated in Seasar)
 */
public class NoSuchMethodRuntimeException extends SRuntimeException {

    private static final long serialVersionUID = -5673845060079098617L;

    private Class targetClass;

    private String methodName;

    private Class[] argTypes;

    public NoSuchMethodRuntimeException(Class targetClass, String methodName, Class[] argTypes, NoSuchMethodException cause) {
        super("ESSR0057", new Object[] { targetClass.getName(), LdiMethodUtil.getSignature(methodName, argTypes), cause }, cause);
        this.targetClass = targetClass;
        this.methodName = methodName;
        this.argTypes = argTypes;
    }

    public Class getTargetClass() {
        return targetClass;
    }

    public String getMethodName() {
        return methodName;
    }

    public Class[] getArgTypes() {
        return argTypes;
    }
}

==> lasta-di-0.6.6-sources.jar: org/lastaflute/di/exception/NoSuchMethodRuntimeException.java <==
/*
 * Copyright 2014-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.lastaflute.di.exception;

import org.lastaflute.di.util.LdiMethodUtil;

/**
 * @author modified by jflute (originated in Seasar)
 */
public class NoSuchMethodRuntimeException extends SRuntimeException {

    private static final long serialVersionUID = -5673845060079098617L;

    private Class<?> targetClass;
    private String methodName;
    private Class<?>[] argTypes;

    public NoSuchMethodRuntimeException(Class<?> targetClass, String methodName, Class<?>[] argTypes, NoSuchMethodException cause) {
        super("ESSR0057", new Object[] { targetClass.getName(), LdiMethodUtil.getSignature(methodName, argTypes), cause }, cause);
        this.targetClass = targetClass;
        this.methodName = methodName;
        this.argTypes = argTypes;
    }

    public Class<?> getTargetClass() {
        return targetClass;
    }

    public String getMethodName() {
        return methodName;
    }

    public Class<?>[] getArgTypes() {
        return argTypes;
    }
}
